<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 *
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
	register_activation_hook( __FILE__, 'rwmb_check_php_version' );

	/**
	 * Display notice for old PHP version.
	 */
	function rwmb_check_php_version() {
		if ( version_compare( phpversion(), '5.3', '<' ) ) {
			die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
		}
	}




	require_once dirname( __FILE__ ) . '/inc/loader.php';
	$rwmb_loader = new RWMB_Loader();
	$rwmb_loader->init();


	add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

	$prefix = '_cmb_';


  // Open Code


    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('post'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Single Select',
                'desc' => 'Select Type Show Single',
                'id'   => $prefix . 'post_select',
                'type'    => 'select',
                'options'   => array(
                    'black'       => 'Dark',
                    'light' => 'Light',
                ),
                'default' => 'single_sidebar',

                'placeholder'     => 'Select Single Type',
            ),
            array(
                'name' => 'Image Recent Post',
                'desc' => 'Show in Recent Post',
                'id'   => $prefix . 'img_recent',
                'type'    => 'file',
            ),
            array(
                'name' => 'Title Recent Post',
                'desc' => 'Input Title Recent Post',
                'id'   => $prefix . 'title_recent',
                'type'    => 'text',
            ),
            array(
                'name' => 'Image blog',
                'desc' => 'Show in Blog Post',
                'id'   => $prefix . 'image_blog',
                'type'    => 'file',
            ),
            array(
                'name' => 'Subtitle blog',
                'desc' => 'Show in Subtitle blog',
                'id'   => $prefix . 'subtitle',
                'type'    => 'text',
            ),
        )
    );
    $meta_boxes[] = array(
        'id'         => 'services_setting',
        'title'      => 'Services Setting',
        'pages'      => array('Services'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Single Select',
                'desc' => 'Select Type Show Single',
                'id'   => $prefix . 'post_select',
                'type'    => 'select',
                'options'   => array(
                    'black'       => 'Dark',
                    'light' => 'Light',
                ),
                'default' => 'single_sidebar',

                'placeholder'     => 'Select Single Type',
            ),
            array(
                'name' => 'Icon ',
                'desc' => 'Icon',
                'id'   => $prefix . 'icon',
                'type'    => 'text',
            ),
            array(
                'name' => 'Subtitle',
                'desc' => 'Subtitle',
                'id'   => $prefix . 'subtitle',
                'type'    => 'text',
            ),
        )
    );
    
    

    
// End Code



    return $meta_boxes;
});
}
