<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBlog extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-blog';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'blog-post' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_blog',
			[
				'label' => esc_html__( 'Blog Post', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Latest News', 'bdevs-elementor' ),
				'default'     => __( ' Latest News ', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Our Blog', 'bdevs-elementor' ),
				'default'     => __( ' Our Blog ', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'read_more',
			[
				'label'       => __( 'Read More', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Read More', 'bdevs-elementor' ),
				'default'     => __( ' Read More ', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '3',
			]
		);

		$this->add_control(
			'orderpost',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'     => esc_html__( 'Order By', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'date'  => esc_html__( 'Date', 'bdevs-elementor' ),
					'title' => esc_html__( 'Title', 'bdevs-elementor' ),
					'rand' => esc_html__( 'Random', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);
		
		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Button', 'bdevs-elementor' ),
				'default'     => __( 'All Posts ', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'link_button',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Link Button', 'bdevs-elementor' ),
				'default'     => __( 'https://shtheme.org/demosd/fredia/?page_id=20 ', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_read_more',
			[
				'label'   => esc_html__( 'Show Read More', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
<section class="blog-grid section-padding bg-gray">
    <div class="container">
        <div class="row">
            <div class="col-md-12 mb-30 animate-box" data-animate-effect="fadeInUp"> 
                <?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
                <span><?php echo wp_kses_post($settings['subheading']); ?></span>
                <?php endif; ?>
                <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
                <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
                <?php endif; ?>
            </div>
        </div>
        <div class="row">
            <div class="col-md-12 owl-carousel owl-theme">
            	<?php 
		            $q = new \WP_Query(array(
		                'post_type'     => 'post',
		                'posts_per_page'=> $number,
		                'orderby'       => $orderby,
		                'order'         => $orderpost,
		            ));
		            $i = 0;
		                while($q->have_posts()): $q->the_post();  
		                $image_blog = get_post_meta(get_the_ID(),'_cmb_image_blog', true);
                        $subtitle = get_post_meta(get_the_ID(),'_cmb_subtitle', true);
		            $i++;
                ?>
                <div class="item list animate-box" data-animate-effect="fadeInUp">
                    <div class="img"> <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($image_blog);?>" alt=""></a> </div>
                    <div class="cont">
                        <a href="#0" class="date"> <span><i><?php the_time('d'); ?></i><?php the_time('M'); ?> </span> </a>
                        <div class="info custom-font">
                            <a href="<?php the_permalink();?>" class="tag"> <span><?php echo esc_attr($subtitle);?></span> </a>
                        </div>
                        <h6>
                            <a href="<?php the_permalink();?>"><?php the_title(); ?></a>
                        </h6> <?php if (( '' !== $settings['read_more'] ) && ( $settings['show_read_more'] )) : ?><a href="<?php the_permalink();?>" class="underline-text"><?php echo wp_kses_post($settings['read_more']); ?></a><?php endif; ?>
                    </div>
                </div>
                <?php endwhile; ?>
            </div>
        </div>
        <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>
        <div class="row">
            <div class="col-md-12 text-right animate-box" data-animate-effect="fadeInUp">
                <p><a href="<?php echo wp_kses_post($settings['link_button']); ?>" class="underline-text"><?php echo wp_kses_post($settings['button']); ?></a></p>
            </div>
        </div>
        <?php endif; ?>
    </div>
</section>
	<?php
	}
}