<?php
if( !class_exists('AArpr_Input_Type_Number') ){
	class AArpr_Input_Type_Number extends AArpr_Settings 
	{
		public $manifest;
        private static $instance;
		
		public $plugin_alias;
		public $box = null;
		

        public static function getInstance( $plugin_alias='', $pms=array() )
        {
            if (null === static::$instance) {
                static::$instance = new static( $plugin_alias, $pms );
            }
            
            return static::$instance;
        }

		public function __construct( $plugin_alias='', $pms=array() )
		{
			parent::__construct( $plugin_alias, $pms );
			$this->plugin_alias = $plugin_alias;

			// load the manifest array
			$this->manifest = $this->options['input-type-number'];
		}

		public function _set_box( $box ) {
			$this->box = $box;
		}
		

		/**
		 * @param string $elm_id
		 * @param string $box_id
		 * @param string $val
		 * @param array $value
		 *
		 * @return string
		 *
		 * @internal
		 */
		protected function _render( $elm_id, $box_id, $val, $attrs ) 
		{
			$attrs = $this->build_element_size( $attrs );
			if( isset($attrs['type']) ) unset( $attrs['type'] );

			$html = array();
			
			$the_id = ( $box_id ) . '-' . esc_attr($elm_id);
			$the_name = ( $box_id ) . '[' . esc_attr($elm_id) . ']';

			$html[] = '<div class="' . $this->plugin_alias . '-item-' . ( $this->manifest['id'] ) . '"';
			$html[] = ' style="';
			if( isset($attrs['width']) && trim($attrs['width']) != "" ){
				$html[] = 'width:' . $attrs['width'] . ';';
			}
			if( isset($attrs['height']) && trim($attrs['height']) != "" ){
				$html[] = 'height:' . $attrs['height'] . ';';
			}
			$html[] = '">';
			$html[] = '<input type="number"';
			$html[] = ' value="' . esc_attr($val) . '"';
			$html[] = ' id="' . $the_id . '"';
			$html[] = ' name="' . $the_name . '"';
			
			$default_attrs = array(
				'max',
				'maxlength',
				'min',
				'pattern',
				'readonly',
				'required',
				'step'
			);

			if( count($default_attrs) > 0 ){
				foreach ($default_attrs as $attr) {
					if( isset($attrs[$attr]) && trim($attrs[$attr]) != "" ){
						$html[] =  ' ' . ( $attr ) . '="' . $attrs[$attr] . '"';
					}
				}
			}
			
			$html[] = ' style="';
			if( isset($attrs['width']) && trim($attrs['width']) != "" ){
				$html[] = 'width:' . '100%' . ';';
			}
			if( isset($attrs['height']) && trim($attrs['height']) != "" ){
				$html[] = 'height:' . '100%' . ';';
			}
			$html[] = '"';
			
			$html[] = '/>';
			$html[] = '</div>';

			return implode( "\n", $html );
		}

		public function options()
		{
			$options = array();

			$options['label'] = array(
		        'type' 			=> 'text',
		        'placeholder' 	=> esc_html__( 'Option label (Title)', 'SMPNEW'),
		        'title' 		=> esc_html__( 'Title', 'SMPNEW'),
		        'force_width' 	=> '60%',
		        'desc' 			=> esc_html__( 'Type your option label here. This will be autoconvert to option alias.', 'SMPNEW' )
		    );

		    $options['desc'] = array(
		        'type' 			=> 'textarea',
		        'placeholder' 	=> esc_html__( 'Option description', 'SMPNEW'),
		        'title' 		=> esc_html__( 'Description', 'SMPNEW'),
		        'force_width' 	=> '70%',
		        'desc' 			=> esc_html__( 'Option description here', 'SMPNEW' )
		    );
			
		    $options['std'] = array(
		        'type' 			=> 'text',
		        'title' 		=> esc_html__( 'Option default', 'SMPNEW'),
		        'force_width' 	=> '20%',
		        'desc' 			=> esc_html__( 'Type your option default value.', 'SMPNEW' )
		    );
			
		    $options['size'] = array(
		        'type' 			=> 'select',
		        'std'			=> '50%',
		        'title' 		=>  esc_html__( 'Option size', 'SMPNEW'),
		        'force_width' 	=> '40%',
		        'desc' 			=> esc_html__( 'Select your option size', 'SMPNEW' ),
		        'values'		=> $this->build_size_array()
		    );
			
			$options['width'] = array(
		        'type' 			=> 'text',
		        'placeholder' 	=> esc_html__( 'Option width (for style property)', 'SMPNEW'),
		        'title' 		=> esc_html__( 'Width', 'SMPNEW'),
		        'force_width' 	=> '60%',
		        'desc' 			=> esc_html__( 'Type your option width here. This will be autoconvert to option alias.', 'SMPNEW' )
		    );
			
			$options['height'] = array(
		        'type' 			=> 'text',
		        'placeholder' 	=> esc_html__( 'Option height (for style property)', 'SMPNEW'),
		        'title' 		=> esc_html__( 'Height', 'SMPNEW'),
		        'force_width' 	=> '60%',
		        'desc' 			=> esc_html__( 'Type your option height here. This will be autoconvert to option alias.', 'SMPNEW' )
		    );

		    $options['max'] = array(
		        'type' 			=> 'text',
		        'title' 		=> esc_html__( 'Max', 'SMPNEW'),
		        'force_width' 	=> '20%',
		        'desc' 			=> esc_html__( 'Specifies the maximum value for an input field', 'SMPNEW' )
		    );

		    $options['maxlength'] = array(
		        'type' 			=> 'text',
		        'title' 		=> esc_html__( 'Maxlength', 'SMPNEW'),
		        'force_width' 	=> '20%',
		        'desc' 			=> esc_html__( 'Specifies the maximum number of character for an input field', 'SMPNEW' )
		    );

		    $options['min'] = array(
		        'type' 			=> 'text',
		        'title' 		=> esc_html__( 'Min', 'SMPNEW'),
		        'force_width' 	=> '20%',
		        'desc' 			=> esc_html__( 'Specifies the minimum value for an input field', 'SMPNEW' )
		    );

		    $options['pattern'] = array(
		        'type' 			=> 'text',
		        'title' 		=> esc_html__( 'Pattern', 'SMPNEW'),
		        'force_width' 	=> '60%',
		        'desc' 			=> esc_html__( 'Specifies a regular expression to check the input value against', 'SMPNEW' )
		    );
			
		    $options['readonly'] = array(
		        'type' 			=> 'select',
		        'std'			=> 'no',
		        'title' 		=>  esc_html__( 'Readonly', 'SMPNEW'),
		        'force_width' 	=> '20%',
		        'desc' 			=> esc_html__( 'Select your option readonly status', 'SMPNEW' ),
		        'values'		=> array(
		        	'yes' => 'Yes',
		        	'no' => 'No'
		        )
		    );

		    $options['required'] = array(
		        'type' 			=> 'select',
		        'std'			=> 'no',
		        'title' 		=>  esc_html__( 'Required', 'SMPNEW'),
		        'force_width' 	=> '20%',
		        'desc' 			=> esc_html__( 'Select your option required status', 'SMPNEW' ),
		        'values'		=> array(
		        	'yes' => 'Yes',
		        	'no' => 'No'
		        )
		    );

		    $options['step'] = array(
		        'type' 			=> 'text',
		        'title' 		=> esc_html__( 'Step', 'SMPNEW'),
		        'force_width' 	=> '30%',
		        'desc' 			=> esc_html__( 'Specifies the legal number intervals for an input field', 'SMPNEW' )
		    );

			return $options;
		}
	}
}