<?php
if( !class_exists('AArpr_Option_Type_Multiselect') ){
	class AArpr_Option_Type_Multiselect extends AArpr_Settings 
	{
		public $manifest;
        private static $instance;
		
		public $plugin_alias;
		public $box = null;
		

        public static function getInstance( $plugin_alias='', $pms=array() )
        {
            if (null === static::$instance) {
                static::$instance = new static( $plugin_alias, $pms );
            }
            
            return static::$instance;
        }

		public function __construct( $plugin_alias='', $pms=array() )
		{
			parent::__construct( $plugin_alias, $pms );
			$this->plugin_alias = $plugin_alias;

			// load the manifest array
			$this->manifest = $this->options['multiselect'];
		}

		public function _set_box( $box ) {
			$this->box = $box;
		}


		/**
		 * @param string $elm_id
		 * @param string $box_id
		 * @param string $val
		 * @param array $value
		 *
		 * @return string
		 *
		 * @internal
		 */
		protected function _render( $elm_id, $box_id, $val, $attrs ) 
		{
			$attrs = $this->build_element_size( $attrs );
			if( isset($attrs['type']) ) unset( $attrs['type'] );

			$html = array();
			
			$the_id = ( $box_id ) . '-' . esc_attr($elm_id);
			$the_name = ( $box_id ) . '[' . esc_attr($elm_id) . ']';

			$html[] = '<div class="' . $this->plugin_alias . '-item-' . ( $this->manifest['id'] ) . '"';
			$html[] = ' style="';
			if( isset($attrs['width']) && trim($attrs['width']) != "" ){
				$html[] = 'width:' . $attrs['width'] . ';';
			}
			if( isset($attrs['height']) && trim($attrs['height']) != "" ){
				$html[] = 'height:' . $attrs['height'] . ';';
			}
			$html[] = '">';
			$html[] = '<select multiple="multiple"';
			$html[] = ' id="' . $the_id . '"';
			$html[] = ' name="' . $the_name . '[]"';

			$html[] = ' style="';
			if( isset($attrs['width']) && trim($attrs['width']) != "" ){
				$html[] = 'width:' . '100%' . ';';
			}
			if( isset($attrs['height']) && trim($attrs['height']) != "" ){
				$html[] = 'height:' . '100%' . ';';
			}
			$html[] = '"';

			$html[] = '>';

			//if( isset($attrs['label']) && trim($attrs['label']) != "" ){
			//	$html[] = '<option disabled selected value="">' . $attrs['label'] . '</option>';
			//}
			
			$attrs['options'] = (array) $attrs['options'];
			foreach ($attrs['options'] as $key => $option) {
				$selected = '';
				if ( '' != $val ) {
					if ( in_array($key, $val) ) {
						$selected = ' selected="selected"';
					}
				}
				$html[] = '<option' . $selected . ' value="' . esc_attr($key) . '">' . esc_html($option) . '</option>';
			}
			
			$html[] = '</select>';
			$html[] = '</div>';

			return implode( "\n", $html );
		}

		public function options()
		{
			$options = array();

			$options['label'] = array(
		        'type' 			=> 'text',
		        'placeholder' 	=> esc_html__( 'Option label (Title)', 'SMPNEW'),
		        'title' 		=> esc_html__( 'Title', 'SMPNEW'),
		        'force_width' 	=> '60%',
		        'desc' 			=> esc_html__( 'Type your option label here. This will be autoconvert to option alias.', 'SMPNEW' )
		    );

		    $options['desc'] = array(
		        'type' 			=> 'textarea',
		        'placeholder' 	=> esc_html__( 'Option description', 'SMPNEW'),
		        'title' 		=> esc_html__( 'Description', 'SMPNEW'),
		        'force_width' 	=> '70%',
		        'desc' 			=> esc_html__( 'Option description here', 'SMPNEW' )
		    );
			
		    $options['std'] = array(
		        'type' 			=> 'text',
		        'title' 		=> esc_html__( 'Option default', 'SMPNEW'),
		        'force_width' 	=> '20%',
		        'desc' 			=> esc_html__( 'Type your option default value.', 'SMPNEW' )
		    );
			
		    $options['size'] = array(
		        'type' 			=> 'select',
		        'std'			=> '50%',
		        'title' 		=>  esc_html__( 'Option size', 'SMPNEW'),
		        'force_width' 	=> '40%',
		        'desc' 			=> esc_html__( 'Select your option size', 'SMPNEW' ),
		        'values'		=> $this->build_size_array()
		    );
			
			$options['width'] = array(
		        'type' 			=> 'text',
		        'placeholder' 	=> esc_html__( 'Option width (for style property)', 'SMPNEW'),
		        'title' 		=> esc_html__( 'Width', 'SMPNEW'),
		        'force_width' 	=> '60%',
		        'desc' 			=> esc_html__( 'Type your option width here. This will be autoconvert to option alias.', 'SMPNEW' )
		    );
			
			$options['height'] = array(
		        'type' 			=> 'text',
		        'placeholder' 	=> esc_html__( 'Option height (for style property)', 'SMPNEW'),
		        'title' 		=> esc_html__( 'Height', 'SMPNEW'),
		        'force_width' 	=> '60%',
		        'desc' 			=> esc_html__( 'Type your option height here. This will be autoconvert to option alias.', 'SMPNEW' )
		    );

			return $options;
		}
	}
}